
import React from 'react';
import { Avatar } from './avatar';

describe('<Avatar/>', () => {
  let props;
  let wrapper;

  const baseProps = {
    length: '100',
  };

  test('should render an avatar with the default user icon', () => {
    wrapper = shallow(<Avatar {...baseProps} />);
    expect(wrapper).toMatchSnapshot();
  });

  test('should render an avatar using the given url', () => {
    props = {
      ...baseProps,
      url: 'http://localhost/test-user/avtr',
    };
    wrapper = shallow(<Avatar {...props} />);
    expect(wrapper).toMatchSnapshot();
  });

  test('should render higher dimension if exists', () => {
    props = {
      ...baseProps,
      length: '201',
      url: 'http://localhost/test-user/avtr',
    };
    wrapper = shallow(<Avatar {...props} />);
    expect(wrapper).toMatchSnapshot();
  });

  test('should render same dimension if no higher is available', () => {
    props = {
      ...baseProps,
      length: '480',
      url: 'http://localhost/test-user/avtr',
    };
    wrapper = shallow(<Avatar {...props} />);
    expect(wrapper).toMatchSnapshot();
  });

  test('should return doubled size if exist', () => {
    props = {
      ...baseProps,
      length: '48',
      url: 'http://localhost/test-user/avtr',
    };
    wrapper = shallow(<Avatar {...props} />);
    expect(wrapper).toMatchSnapshot();
  });

  test('should render an avatar using the given tag', () => {
    props = {
      ...baseProps,
      tag: 'section',
      url: 'http://localhost/test-user/avtr',
    };
    wrapper = shallow(<Avatar {...props} />);
    expect(wrapper).toMatchSnapshot();
  });

  test('should render an avatar using the given class name', () => {
    props = {
      ...baseProps,
      className: 'photo',
    };
    wrapper = shallow(<Avatar {...props} />);
    expect(wrapper).toMatchSnapshot();
  });
});
